from typing import Optional

class KbClient:
    def __init__(self,):
        pass

    def create_kb(self, kb_name: str, kb_description: str, kb_type: str, kb_content: str):
        pass

    def get_kb(self, kb_id: str):
        pass